@@ -74,7 +74,7 @@ class PeUser(BaseModel):
         return f"{delta.years} år, {delta.months} mån"
 
     def days_to_birthday(self, from_date=date.today()) -> int:
-        return (self.next_birthday - from_date).days
+        return (self.next_birthday() - from_date).days
 
     def next_birthday(self, from_date=date.today()) -> date:
         next_birthday = datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").replace(year=from_date.year).date()
